aboutsummaryrefslogtreecommitdiff
path: root/src/libstore/legacy-ssh-store.cc
diff options
context:
space:
mode:
authoreldritch horrors <pennae@lix.systems>2024-03-04 04:24:23 +0100
committereldritch horrors <pennae@lix.systems>2024-03-04 04:36:58 +0100
commit6897e238bd0c730af224b928ec8746781df67ad2 (patch)
tree50ce7ddeda203a12c7d67080ef611f56d59678c2 /src/libstore/legacy-ssh-store.cc
parentda0aa66d98b8b46253dd968cfaae61d872569c9b (diff)
Merge pull request #9099 from obsidiansystems/common-proto
Factor out bits of the worker protocol to use elsewhere (cherry picked from commit 4b1a97338f517f45e6169d3d8845c5caa5724e97) Change-Id: If93afa0f8b1cf9b0e705b34fa71e6fd708752758
Diffstat (limited to 'src/libstore/legacy-ssh-store.cc')
-rw-r--r--src/libstore/legacy-ssh-store.cc44
1 files changed, 22 insertions, 22 deletions
diff --git a/src/libstore/legacy-ssh-store.cc b/src/libstore/legacy-ssh-store.cc
index 78b05031a..7bf4476d0 100644
--- a/src/libstore/legacy-ssh-store.cc
+++ b/src/libstore/legacy-ssh-store.cc
@@ -6,8 +6,8 @@
#include "build-result.hh"
#include "store-api.hh"
#include "path-with-outputs.hh"
-#include "worker-protocol.hh"
-#include "worker-protocol-impl.hh"
+#include "common-protocol.hh"
+#include "common-protocol-impl.hh"
#include "ssh.hh"
#include "derivations.hh"
#include "callback.hh"
@@ -50,37 +50,37 @@ struct LegacySSHStore : public virtual LegacySSHStoreConfig, public virtual Stor
bool good = true;
/**
* Coercion to `WorkerProto::ReadConn`. This makes it easy to use the
* factored out worker protocol searlizers with a
* `LegacySSHStore::Connection`.
*
* The worker protocol connection types are unidirectional, unlike
* this type.
*
* @todo Use server protocol serializers, not worker protocol
* serializers, once we have made that distiction.
*/
- operator WorkerProto::ReadConn ()
+ operator CommonProto::ReadConn ()
{
- return WorkerProto::ReadConn {
+ return CommonProto::ReadConn {
.from = from,
};
}
/*
* Coercion to `WorkerProto::WriteConn`. This makes it easy to use the
* factored out worker protocol searlizers with a
* `LegacySSHStore::Connection`.
*
* The worker protocol connection types are unidirectional, unlike
* this type.
*
* @todo Use server protocol serializers, not worker protocol
* serializers, once we have made that distiction.
*/
- operator WorkerProto::WriteConn ()
+ operator CommonProto::WriteConn ()
{
- return WorkerProto::WriteConn {
+ return CommonProto::WriteConn {
.to = to,
};
}
@@ -183,7 +183,7 @@ struct LegacySSHStore : public virtual LegacySSHStoreConfig, public virtual Stor
auto deriver = readString(conn->from);
if (deriver != "")
info->deriver = parseStorePath(deriver);
- info->references = WorkerProto::Serialise<StorePathSet>::read(*this, *conn);
+ info->references = CommonProto::Serialise<StorePathSet>::read(*this, *conn);
readLongLong(conn->from); // download size
info->narSize = readLongLong(conn->from);
@@ -217,7 +217,7 @@ struct LegacySSHStore : public virtual LegacySSHStoreConfig, public virtual Stor
<< printStorePath(info.path)
<< (info.deriver ? printStorePath(*info.deriver) : "")
<< info.narHash.to_string(Base16, false);
- WorkerProto::write(*this, *conn, info.references);
+ CommonProto::write(*this, *conn, info.references);
conn->to
<< info.registrationTime
<< info.narSize
@@ -246,7 +246,7 @@ struct LegacySSHStore : public virtual LegacySSHStoreConfig, public virtual Stor
conn->to
<< exportMagic
<< printStorePath(info.path);
- WorkerProto::write(*this, *conn, info.references);
+ CommonProto::write(*this, *conn, info.references);
conn->to
<< (info.deriver ? printStorePath(*info.deriver) : "")
<< 0
@@ -331,7 +331,7 @@ public:
if (GET_PROTOCOL_MINOR(conn->remoteVersion) >= 3)
conn->from >> status.timesBuilt >> status.isNonDeterministic >> status.startTime >> status.stopTime;
if (GET_PROTOCOL_MINOR(conn->remoteVersion) >= 6) {
- auto builtOutputs = WorkerProto::Serialise<DrvOutputs>::read(*this, *conn);
+ auto builtOutputs = CommonProto::Serialise<DrvOutputs>::read(*this, *conn);
for (auto && [output, realisation] : builtOutputs)
status.builtOutputs.insert_or_assign(
std::move(output.outputName),
@@ -409,10 +409,10 @@ public:
conn->to
<< ServeProto::Command::QueryClosure
<< includeOutputs;
- WorkerProto::write(*this, *conn, paths);
+ CommonProto::write(*this, *conn, paths);
conn->to.flush();
- for (auto & i : WorkerProto::Serialise<StorePathSet>::read(*this, *conn))
+ for (auto & i : CommonProto::Serialise<StorePathSet>::read(*this, *conn))
out.insert(i);
}
@@ -425,10 +425,10 @@ public:
<< ServeProto::Command::QueryValidPaths
<< false // lock
<< maybeSubstitute;
- WorkerProto::write(*this, *conn, paths);
+ CommonProto::write(*this, *conn, paths);
conn->to.flush();
- return WorkerProto::Serialise<StorePathSet>::read(*this, *conn);
+ return CommonProto::Serialise<StorePathSet>::read(*this, *conn);
}
void connect() override
@@ -50,37 +50,37 @@ struct LegacySSHStore : public virtual LegacySSHStoreConfig, public virtual Stor
bool good = true;
/**
- * Coercion to `WorkerProto::ReadConn`. This makes it easy to use the
- * factored out worker protocol searlizers with a
+ * Coercion to `CommonProto::ReadConn`. This makes it easy to use the
+ * factored out common protocol serialisers with a
* `LegacySSHStore::Connection`.
*
@@ -50,37 +50,37 @@ struct LegacySSHStore : public virtual LegacySSHStoreConfig, public virtual Stor
* `LegacySSHStore::Connection`.
*
- * The worker protocol connection types are unidirectional, unlike
+ * The common protocol connection types are unidirectional, unlike
* this type.
*
@@ -50,37 +50,37 @@ struct LegacySSHStore : public virtual LegacySSHStoreConfig, public virtual Stor
* this type.
*
- * @todo Use server protocol serializers, not worker protocol
+ * @todo Use server protocol serializers, not common protocol
* serializers, once we have made that distiction.
*/
@@ -50,37 +50,37 @@ struct LegacySSHStore : public virtual LegacySSHStoreConfig, public virtual Stor
}
/*
- * Coercion to `WorkerProto::WriteConn`. This makes it easy to use the
- * factored out worker protocol searlizers with a
+ * Coercion to `CommonProto::WriteConn`. This makes it easy to use the
+ * factored out common protocol searlizers with a
* `LegacySSHStore::Connection`.
*
@@ -50,37 +50,37 @@ struct LegacySSHStore : public virtual LegacySSHStoreConfig, public virtual Stor
* `LegacySSHStore::Connection`.
*
- * The worker protocol connection types are unidirectional, unlike
+ * The common protocol connection types are unidirectional, unlike
* this type.
*
@@ -50,37 +50,37 @@ struct LegacySSHStore : public virtual LegacySSHStoreConfig, public virtual Stor
* this type.
*
- * @todo Use server protocol serializers, not worker protocol
+ * @todo Use server protocol serializers, not common protocol
* serializers, once we have made that distiction.
*/